@@ -32,6 +32,9 @@ Package with client-side python modules and command line utilities.
 """
 
 import logging
+
+from lmi.shell import LMINamespace
+from lmi.shell import LMIExceptions
 from lmi.scripts.common.configuration import Configuration
 
 def get_logger(module_name):
@@ -59,3 +62,36 @@ def get_logger(module_name):
         """ Callable used to obtain current logger object. """
         return logging.getLogger(module_name)
     return _logger
+
+def get_computer_system(ns):
+    """
+    Obtain an instance of ``CIM_ComputerSystem`` or its subclass. Preferred
+    class name can be configured in configuration file. If such class does
+    not exist, a base class (``CIM_ComputerSystem``) is enumerated instead.
+    First feasible instance is cached and returned.
+
+    :param ns: Namespace object where to look for computer system class.
+    :type ns: :py:class:`lmi.shell.LMINamespace`
+    :returns: Instance of ``CIM_ComputerSystem``.
+    :rtype: :py:class:`lmi.shell.LMIInstance`.
+    """
+    if not isinstance(ns, LMINamespace):
+        raise TypeError("ns must be an instance of LMINamespace")
+    if not hasattr(get_computer_system, '_cs_cache'):
+        get_computer_system._cs_cache = {}
+    ns_path = ns.connection.uri + '/' + ns.name
+    if not ns_path in get_computer_system._cs_cache:
+        logger = logging.getLogger(__name__)
+        config = Configuration.get_instance()
+        try:
+            get_computer_system._cs_cache[ns_path] = cs = \
+                    getattr(ns, config.system_class_name).first_instance()
+        except LMIExceptions.LMIClassNotFound:
+            logger.warn('failed to get instance of %s on host "%s"'
+                    ' - falling back to CIM_ComputerSystem',
+                    config.system_class_name, ns.connection.uri)
+            get_computer_system._cs_cache[ns_path] = cs = \
+                    ns.CIM_ComputerSystem.first_instance_name()
+        logger.debug('loaded instance instance of %s:%s for host "%s"',
+            ns.name, cs.classname, ns.connection.uri)
+    return get_computer_system._cs_cache[ns_path]
